# WeeklyBillCycleDay

Day of the week that each billing period begins on. Only applicable if the value of the `billCycleType` field is `SpecificDayofWeek`. 

## Enum

* `SUNDAY` (value: `'Sunday'`)

* `MONDAY` (value: `'Monday'`)

* `TUESDAY` (value: `'Tuesday'`)

* `WEDNESDAY` (value: `'Wednesday'`)

* `THURSDAY` (value: `'Thursday'`)

* `FRIDAY` (value: `'Friday'`)

* `SATURDAY` (value: `'Saturday'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


